package com.dylanvann.fastimage;

import android.text.TextUtils;
import android.util.Log;

import com.bumptech.glide.Glide;
import com.bumptech.glide.RequestBuilder;
import com.bumptech.glide.RequestManager;
import com.bumptech.glide.request.RequestOptions;
import com.bumptech.glide.request.target.Target;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.SimpleViewManager;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.ViewProps;
import com.facebook.react.uimanager.annotations.ReactProp;

import java.util.Map;

import javax.annotation.Nullable;

import static com.dylanvann.fastimage.FastImageRequestListener.REACT_ON_ERROR_EVENT;
import static com.dylanvann.fastimage.FastImageRequestListener.REACT_ON_LOAD_END_EVENT;
import static com.dylanvann.fastimage.FastImageRequestListener.REACT_ON_LOAD_EVENT;


class FastImageViewManager extends SimpleViewManager<FastImageViewWithUrl>  {
    private static final String REACT_CLASS = "FastImageView";
    private static RequestManager requestManager = null;



    @Override
    public String getName() {
        return REACT_CLASS;
    }

    @Override
    protected FastImageViewWithUrl createViewInstance(ThemedReactContext reactContext) {
        if (requestManager == null) {
            requestManager = Glide.with(reactContext.getApplicationContext());
        }
        return new FastImageViewWithUrl(reactContext);
    }

    @ReactProp(name = "source")
    public void setSrc(FastImageViewWithUrl view, @Nullable ReadableMap source) {
        // Get the GlideUrl which contains header info.
        final FastImageSource imageSource = FastImageViewConverter.getImageSource(view.getContext(), source);
        view.glideUrl = imageSource;
        view.source=source;

    }

    @ReactProp(name = ViewProps.RESIZE_MODE)
    public void setResizeMode(FastImageViewWithUrl view, String resizeMode) {
        view.resizeMode = resizeMode;
    }


    @ReactProp(name = "useOriginalSize")
    public void setResizeMode(FastImageViewWithUrl view, boolean useOriginalSize) {
        view.useOriginalSize = useOriginalSize;
    }

    @Override
    protected void onAfterUpdateTransaction(FastImageViewWithUrl view) {

        FastImageViewWithUrl.ScaleType scaleType = FastImageViewConverter.getScaleType(view.resizeMode);
        view.setScaleType(scaleType);

        ThemedReactContext context = (ThemedReactContext) view.getContext();


        RequestBuilder requestBuilder = requestManager
                .load(view.glideUrl.getSourceForLoad())
                .apply(FastImageViewConverter.getOptions(context,  view.glideUrl, view.source))
                .listener(new FastImageRequestListener());

        if(!TextUtils.isEmpty(view.defaultSource)){
            requestBuilder.thumbnail(requestManager.load(view.defaultSource));
        }

        if(view.dontTransform){
            requestBuilder.dontTransform();
        }

        if(view.useOriginalSize){
            requestBuilder.override(Target.SIZE_ORIGINAL, Target.SIZE_ORIGINAL);
        }

        requestBuilder.into(view);
        super.onAfterUpdateTransaction(view);
    }

    @Override
    public Map<String, Object> getExportedCustomDirectEventTypeConstants() {
        return MapBuilder.<String, Object>builder()
                .put(REACT_ON_LOAD_EVENT, MapBuilder.of("registrationName", REACT_ON_LOAD_EVENT))
                .put(REACT_ON_ERROR_EVENT, MapBuilder.of("registrationName", REACT_ON_ERROR_EVENT))
                .put(REACT_ON_LOAD_END_EVENT, MapBuilder.of("registrationName", REACT_ON_LOAD_END_EVENT))
                .build();
    }


    @ReactProp(name = "defaultSource")
    public void setDefaultSource(FastImageViewWithUrl view, @Nullable ReadableMap defaultSource) {
        try {
            view.defaultSource = defaultSource.getString("uri");
        } catch (Exception e) {
        }
    }

    @ReactProp(name = "dontTransform")
    public void dontTransform(FastImageViewWithUrl view, @Nullable Boolean dontTransform) {
        try {
            view.dontTransform = dontTransform;
        } catch (Exception e) {
        }
    }


    @Override
    public void onDropViewInstance(FastImageViewWithUrl view) {
//         This will cancel existing requests.

        if (requestManager != null) {
            requestManager.clear(view);
        }
        super.onDropViewInstance(view);
    }

}
